Examples
use AronIS_GPS_Crate::GPS;
use rpi_embedded::uart::{Uart,Parity};
fn main(){
let mut gps = gps::GPS::new();
loop{
gps.decoder();
}
}Important info:
The output from the GPS is printed to the terminal and can additionally be read by reding the values from the struct
fx. in the example: pgs.altitude;